@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
@@ -27,8 +25,12 @@
 #include <glib.h>
 
 #define GDK_MAJOR_VERSION (3)
-#define GDK_MINOR_VERSION (8)
-#define GDK_MICRO_VERSION (2)
+#define GDK_MINOR_VERSION (20)
+#define GDK_MICRO_VERSION (6)
+
+#ifndef _GDK_EXTERN
+#define _GDK_EXTERN extern
+#endif
 
 /**
  * GDK_DISABLE_DEPRECATION_WARNINGS:
@@ -39,13 +41,13 @@
  */
 
 #ifdef GDK_DISABLE_DEPRECATION_WARNINGS
-#define GDK_DEPRECATED
-#define GDK_DEPRECATED_FOR(f)
-#define GDK_UNAVAILABLE(maj,min)
+#define GDK_DEPRECATED _GDK_EXTERN
+#define GDK_DEPRECATED_FOR(f) _GDK_EXTERN
+#define GDK_UNAVAILABLE(maj,min) _GDK_EXTERN
 #else
-#define GDK_DEPRECATED G_DEPRECATED
-#define GDK_DEPRECATED_FOR(f) G_DEPRECATED_FOR(f)
-#define GDK_UNAVAILABLE(maj,min) G_UNAVAILABLE(maj,min)
+#define GDK_DEPRECATED G_DEPRECATED _GDK_EXTERN
+#define GDK_DEPRECATED_FOR(f) G_DEPRECATED_FOR(f) _GDK_EXTERN
+#define GDK_UNAVAILABLE(maj,min) G_UNAVAILABLE(maj,min) _GDK_EXTERN
 #endif
 
 /* XXX: Every new stable minor release bump should add a macro here */
@@ -100,6 +102,65 @@
  */
 #define GDK_VERSION_3_8         (G_ENCODE_VERSION (3, 8))
 
+/**
+ * GDK_VERSION_3_10:
+ *
+ * A macro that evaluates to the 3.10 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.10
+ */
+#define GDK_VERSION_3_10        (G_ENCODE_VERSION (3, 10))
+
+/**
+ * GDK_VERSION_3_12:
+ *
+ * A macro that evaluates to the 3.12 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.12
+ */
+#define GDK_VERSION_3_12        (G_ENCODE_VERSION (3, 12))
+
+/**
+ * GDK_VERSION_3_14:
+ *
+ * A macro that evaluates to the 3.14 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.14
+ */
+#define GDK_VERSION_3_14        (G_ENCODE_VERSION (3, 14))
+
+/**
+ * GDK_VERSION_3_16:
+ *
+ * A macro that evaluates to the 3.16 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.16
+ */
+#define GDK_VERSION_3_16        (G_ENCODE_VERSION (3, 16))
+
+/**
+ * GDK_VERSION_3_18:
+ *
+ * A macro that evaluates to the 3.18 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.18
+ */
+#define GDK_VERSION_3_18        (G_ENCODE_VERSION (3, 18))
+
+/**
+ * GDK_VERSION_3_20:
+ *
+ * A macro that evaluates to the 3.20 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.18
+ */
+#define GDK_VERSION_3_20        (G_ENCODE_VERSION (3, 20))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -169,76 +230,163 @@
 #error "GDK_VERSION_MIN_REQUIRED must be >= GDK_VERSION_3_0"
 #endif
 
+#define GDK_AVAILABLE_IN_ALL                  _GDK_EXTERN
+
 /* XXX: Every new stable minor release should add a set of macros here */
 
 #if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_0
 # define GDK_DEPRECATED_IN_3_0                GDK_DEPRECATED
 # define GDK_DEPRECATED_IN_3_0_FOR(f)         GDK_DEPRECATED_FOR(f)
 #else
-# define GDK_DEPRECATED_IN_3_0
-# define GDK_DEPRECATED_IN_3_0_FOR(f)
+# define GDK_DEPRECATED_IN_3_0                _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_0_FOR(f)         _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_0
 # define GDK_AVAILABLE_IN_3_0                 GDK_UNAVAILABLE(3, 0)
 #else
-# define GDK_AVAILABLE_IN_3_0
+# define GDK_AVAILABLE_IN_3_0                 _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_2
 # define GDK_DEPRECATED_IN_3_2                GDK_DEPRECATED
 # define GDK_DEPRECATED_IN_3_2_FOR(f)         GDK_DEPRECATED_FOR(f)
 #else
-# define GDK_DEPRECATED_IN_3_2
-# define GDK_DEPRECATED_IN_3_2_FOR(f)
+# define GDK_DEPRECATED_IN_3_2                _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_2_FOR(f)         _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_2
 # define GDK_AVAILABLE_IN_3_2                 GDK_UNAVAILABLE(3, 2)
 #else
-# define GDK_AVAILABLE_IN_3_2
+# define GDK_AVAILABLE_IN_3_2                 _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_4
 # define GDK_DEPRECATED_IN_3_4                GDK_DEPRECATED
 # define GDK_DEPRECATED_IN_3_4_FOR(f)         GDK_DEPRECATED_FOR(f)
 #else
-# define GDK_DEPRECATED_IN_3_4
-# define GDK_DEPRECATED_IN_3_4_FOR(f)
+# define GDK_DEPRECATED_IN_3_4                _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_4_FOR(f)         _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_4
 # define GDK_AVAILABLE_IN_3_4                 GDK_UNAVAILABLE(3, 4)
 #else
-# define GDK_AVAILABLE_IN_3_4
+# define GDK_AVAILABLE_IN_3_4                 _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_6
 # define GDK_DEPRECATED_IN_3_6                GDK_DEPRECATED
 # define GDK_DEPRECATED_IN_3_6_FOR(f)         GDK_DEPRECATED_FOR(f)
 #else
-# define GDK_DEPRECATED_IN_3_6
-# define GDK_DEPRECATED_IN_3_6_FOR(f)
+# define GDK_DEPRECATED_IN_3_6                _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_6_FOR(f)         _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_6
 # define GDK_AVAILABLE_IN_3_6                 GDK_UNAVAILABLE(3, 6)
 #else
-# define GDK_AVAILABLE_IN_3_6
+# define GDK_AVAILABLE_IN_3_6                 _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_8
 # define GDK_DEPRECATED_IN_3_8                GDK_DEPRECATED
 # define GDK_DEPRECATED_IN_3_8_FOR(f)         GDK_DEPRECATED_FOR(f)
 #else
-# define GDK_DEPRECATED_IN_3_8
-# define GDK_DEPRECATED_IN_3_8_FOR(f)
+# define GDK_DEPRECATED_IN_3_8                _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_8_FOR(f)         _GDK_EXTERN
 #endif
 
 #if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_8
 # define GDK_AVAILABLE_IN_3_8                 GDK_UNAVAILABLE(3, 8)
 #else
-# define GDK_AVAILABLE_IN_3_8
+# define GDK_AVAILABLE_IN_3_8                 _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_10
+# define GDK_DEPRECATED_IN_3_10               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_10_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_10               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_10_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_10
+# define GDK_AVAILABLE_IN_3_10                GDK_UNAVAILABLE(3, 10)
+#else
+# define GDK_AVAILABLE_IN_3_10                _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_12
+# define GDK_DEPRECATED_IN_3_12               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_12_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_12               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_12_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_12
+# define GDK_AVAILABLE_IN_3_12                GDK_UNAVAILABLE(3, 12)
+#else
+# define GDK_AVAILABLE_IN_3_12                _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_14
+# define GDK_DEPRECATED_IN_3_14               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_14_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_14               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_14_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_14
+# define GDK_AVAILABLE_IN_3_14                GDK_UNAVAILABLE(3, 14)
+#else
+# define GDK_AVAILABLE_IN_3_14                _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_16
+# define GDK_DEPRECATED_IN_3_16               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_16_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_16               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_16_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_16
+# define GDK_AVAILABLE_IN_3_16                GDK_UNAVAILABLE(3, 16)
+#else
+# define GDK_AVAILABLE_IN_3_16                _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_18
+# define GDK_DEPRECATED_IN_3_18               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_18_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_18               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_18_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_18
+# define GDK_AVAILABLE_IN_3_18                GDK_UNAVAILABLE(3, 18)
+#else
+# define GDK_AVAILABLE_IN_3_18                _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_20
+# define GDK_DEPRECATED_IN_3_20               GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_20_FOR(f)        GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_20               _GDK_EXTERN
+# define GDK_DEPRECATED_IN_3_20_FOR(f)        _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_20
+# define GDK_AVAILABLE_IN_3_20                GDK_UNAVAILABLE(3, 20)
+#else
+# define GDK_AVAILABLE_IN_3_20                _GDK_EXTERN
 #endif
 
 #endif  /* __GDK_VERSION_MACROS_H__ */
+
