@@ -16,9 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -28,14 +26,14 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
-#error "Only <gtk/gtk.h> can be included directly."
-#endif
-
 #ifndef __GTK_ENTRY_H__
 #define __GTK_ENTRY_H__
 
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #include <gtk/gtkeditable.h>
 #include <gtk/gtkimcontext.h>
 #include <gtk/gtkmenu.h>
@@ -54,84 +52,82 @@ G_BEGIN_DECLS
 #define GTK_IS_ENTRY_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_ENTRY))
 #define GTK_ENTRY_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ENTRY, GtkEntryClass))
 
+/**
+ * GtkEntryIconPosition:
+ * @GTK_ENTRY_ICON_PRIMARY: At the beginning of the entry (depending on the text direction).
+ * @GTK_ENTRY_ICON_SECONDARY: At the end of the entry (depending on the text direction).
+ *
+ * Specifies the side of the entry at which an icon is placed.
+ *
+ * Since: 2.16
+ */
 typedef enum
 {
   GTK_ENTRY_ICON_PRIMARY,
   GTK_ENTRY_ICON_SECONDARY
 } GtkEntryIconPosition;
 
-typedef struct _GtkEntry       GtkEntry;
-typedef struct _GtkEntryClass  GtkEntryClass;
+typedef struct _GtkEntry              GtkEntry;
+typedef struct _GtkEntryPrivate       GtkEntryPrivate;
+typedef struct _GtkEntryClass         GtkEntryClass;
 
 struct _GtkEntry
 {
-  GtkWidget  widget;
-
-  gchar       *GSEAL (text);                        /* COMPAT: Deprecated, not used. Remove in GTK+ 3.x */
-
-  guint        GSEAL (editable) : 1;
-  guint        GSEAL (visible)  : 1;
-  guint        GSEAL (overwrite_mode) : 1;
-  guint        GSEAL (in_drag) : 1;	            /* FIXME: Should be private?
-                                                       Dragging within the selection */
-
-  guint16      GSEAL (text_length);                 /* COMPAT: Deprecated, not used. Remove in GTK+ 3.x */
-  guint16      GSEAL (text_max_length);             /* COMPAT: Deprecated, not used. Remove in GTK+ 3.x */
-
   /*< private >*/
-  GdkWindow    *GSEAL (text_area);
-  GtkIMContext *GSEAL (im_context);
-  GtkWidget    *GSEAL (popup_menu);
+  GtkWidget  parent_instance;
 
-  gint          GSEAL (current_pos);
-  gint          GSEAL (selection_bound);
-
-  PangoLayout  *GSEAL (cached_layout);
-
-  guint         GSEAL (cache_includes_preedit) : 1;
-  guint         GSEAL (need_im_reset)          : 1;
-  guint         GSEAL (has_frame)              : 1;
-  guint         GSEAL (activates_default)      : 1;
-  guint         GSEAL (cursor_visible)         : 1;
-  guint         GSEAL (in_click)               : 1; /* Flag so we don't select all when clicking in entry to focus in */
-  guint         GSEAL (is_cell_renderer)       : 1;
-  guint         GSEAL (editing_canceled)       : 1; /* Only used by GtkCellRendererText */ 
-  guint         GSEAL (mouse_cursor_obscured)  : 1;
-  guint         GSEAL (select_words)           : 1;
-  guint         GSEAL (select_lines)           : 1;
-  guint         GSEAL (resolved_dir)           : 4; /* PangoDirection */
-  guint         GSEAL (truncate_multiline)     : 1;
-
-  guint         GSEAL (button);
-  guint         GSEAL (blink_timeout);
-  guint         GSEAL (recompute_idle);
-  gint          GSEAL (scroll_offset);
-  gint          GSEAL (ascent);	                    /* font ascent in pango units  */
-  gint          GSEAL (descent);	            /* font descent in pango units */
-
-  guint16       GSEAL (x_text_size);	            /* allocated size, in bytes */
-  guint16       GSEAL (x_n_bytes);	            /* length in use, in bytes */
-
-  guint16       GSEAL (preedit_length);	            /* length of preedit string, in bytes */
-  guint16       GSEAL (preedit_cursor);	            /* offset of cursor within preedit string, in chars */
-
-  gint          GSEAL (dnd_position);		    /* In chars, -1 == no DND cursor */
-
-  gint          GSEAL (drag_start_x);
-  gint          GSEAL (drag_start_y);
-
-  gunichar      GSEAL (invisible_char);
-
-  gint          GSEAL (width_chars);
+  GtkEntryPrivate *priv;
 };
 
+/**
+ * GtkEntryClass:
+ * @parent_class: The parent class.
+ * @populate_popup: Class handler for the #GtkEntry::populate-popup signal. If
+ *   non-%NULL, this will be called to add additional entries to the context
+ *   menu when it is displayed.
+ * @activate: Class handler for the #GtkEntry::activate signal. The default
+ *   implementation calls gtk_window_activate_default() on the entry’s top-level
+ *   window.
+ * @move_cursor: Class handler for the #GtkEntry::move-cursor signal. The
+ *   default implementation specifies the standard #GtkEntry cursor movement
+ *   behavior.
+ * @insert_at_cursor: Class handler for the #GtkEntry::insert-at-cursor signal.
+ *   The default implementation inserts text at the cursor.
+ * @delete_from_cursor: Class handler for the #GtkEntry::delete-from-cursor
+ *   signal. The default implementation deletes the selection or the specified
+ *   number of characters or words.
+ * @backspace: Class handler for the #GtkEntry::backspace signal. The default
+ *   implementation deletes the selection or a single character or word.
+ * @cut_clipboard: Class handler for the #GtkEntry::cut-clipboard signal. The
+ *   default implementation cuts the selection, if one exists.
+ * @copy_clipboard: Class handler for the #GtkEntry::copy-clipboard signal. The
+ *   default implementation copies the selection, if one exists.
+ * @paste_clipboard: Class handler for the #GtkEntry::paste-clipboard signal.
+ *   The default implementation pastes at the current cursor position or over
+ *   the current selection if one exists.
+ * @toggle_overwrite: Class handler for the #GtkEntry::toggle-overwrite signal.
+ *   The default implementation toggles overwrite mode and blinks the cursor.
+ * @get_text_area_size: Calculate the size of the text area, which is its
+ *   allocated width and requested height, minus space for margins and borders.
+ *   This virtual function must be non-%NULL.
+ * @get_frame_size: Calculate the size of the text area frame, which is its
+ *   allocated width and requested height, minus space for margins and borders,
+ *   and taking baseline and text height into account. This virtual function
+ *   must be non-%NULL.
+ *
+ * Class structure for #GtkEntry. All virtual functions have a default
+ * implementation. Derived classes may set the virtual function pointers for the
+ * signal handlers to %NULL, but must keep @get_text_area_size and
+ * @get_frame_size non-%NULL; either use the default implementation, or provide
+ * a custom one.
+ */
 struct _GtkEntryClass
 {
   GtkWidgetClass parent_class;
 
   /* Hook to customize right-click popup */
   void (* populate_popup)   (GtkEntry       *entry,
-                             GtkMenu        *menu);
+                             GtkWidget      *popup);
 
   /* Action signals
    */
@@ -151,183 +147,279 @@ struct _GtkEntryClass
   void (* paste_clipboard)    (GtkEntry             *entry);
   void (* toggle_overwrite)   (GtkEntry             *entry);
 
-  /* hook to add other objects beside the entry (like in GtkSpinButton) */
+  /* hooks to add other objects beside the entry (like in GtkSpinButton) */
   void (* get_text_area_size) (GtkEntry       *entry,
 			       gint           *x,
 			       gint           *y,
 			       gint           *width,
 			       gint           *height);
+  void (* get_frame_size)     (GtkEntry       *entry,
+                               gint           *x,
+                               gint           *y,
+			       gint           *width,
+			       gint           *height);
+
+  /*< private >*/
 
   /* Padding for future expansion */
   void (*_gtk_reserved1)      (void);
   void (*_gtk_reserved2)      (void);
+  void (*_gtk_reserved3)      (void);
+  void (*_gtk_reserved4)      (void);
+  void (*_gtk_reserved5)      (void);
+  void (*_gtk_reserved6)      (void);
+  void (*_gtk_reserved7)      (void);
 };
 
+GDK_AVAILABLE_IN_ALL
 GType      gtk_entry_get_type       		(void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 GtkWidget* gtk_entry_new            		(void);
+GDK_AVAILABLE_IN_ALL
 GtkWidget* gtk_entry_new_with_buffer            (GtkEntryBuffer *buffer);
 
+GDK_AVAILABLE_IN_ALL
 GtkEntryBuffer* gtk_entry_get_buffer            (GtkEntry       *entry);
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_buffer                 (GtkEntry       *entry,
                                                  GtkEntryBuffer *buffer);
 
-GdkWindow *gtk_entry_get_text_window            (GtkEntry      *entry);
+GDK_AVAILABLE_IN_ALL
+void       gtk_entry_get_text_area              (GtkEntry       *entry,
+                                                 GdkRectangle   *text_area);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_visibility 		(GtkEntry      *entry,
 						 gboolean       visible);
+GDK_AVAILABLE_IN_ALL
 gboolean   gtk_entry_get_visibility             (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_invisible_char         (GtkEntry      *entry,
                                                  gunichar       ch);
+GDK_AVAILABLE_IN_ALL
 gunichar   gtk_entry_get_invisible_char         (GtkEntry      *entry);
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_unset_invisible_char       (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_has_frame              (GtkEntry      *entry,
                                                  gboolean       setting);
+GDK_AVAILABLE_IN_ALL
 gboolean   gtk_entry_get_has_frame              (GtkEntry      *entry);
 
-void       gtk_entry_set_inner_border                (GtkEntry        *entry,
-                                                      const GtkBorder *border);
-const GtkBorder* gtk_entry_get_inner_border          (GtkEntry        *entry);
+GDK_DEPRECATED_IN_3_4
+void             gtk_entry_set_inner_border     (GtkEntry        *entry,
+                                                 const GtkBorder *border);
+GDK_DEPRECATED_IN_3_4
+const GtkBorder* gtk_entry_get_inner_border     (GtkEntry        *entry);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_overwrite_mode         (GtkEntry      *entry,
                                                  gboolean       overwrite);
+GDK_AVAILABLE_IN_ALL
 gboolean   gtk_entry_get_overwrite_mode         (GtkEntry      *entry);
 
 /* text is truncated if needed */
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_max_length 		(GtkEntry      *entry,
 						 gint           max);
+GDK_AVAILABLE_IN_ALL
 gint       gtk_entry_get_max_length             (GtkEntry      *entry);
+GDK_AVAILABLE_IN_ALL
 guint16    gtk_entry_get_text_length            (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_activates_default      (GtkEntry      *entry,
                                                  gboolean       setting);
+GDK_AVAILABLE_IN_ALL
 gboolean   gtk_entry_get_activates_default      (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_width_chars            (GtkEntry      *entry,
                                                  gint           n_chars);
+GDK_AVAILABLE_IN_ALL
 gint       gtk_entry_get_width_chars            (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_3_12
+void       gtk_entry_set_max_width_chars        (GtkEntry      *entry,
+                                                 gint           n_chars);
+GDK_AVAILABLE_IN_3_12
+gint       gtk_entry_get_max_width_chars        (GtkEntry      *entry);
+
 /* Somewhat more convenient than the GtkEditable generic functions
  */
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_text                   (GtkEntry      *entry,
                                                  const gchar   *text);
 /* returns a reference to the text */
-const gchar* gtk_entry_get_text                 (GtkEntry      *entry);
+GDK_AVAILABLE_IN_ALL
+const gchar* gtk_entry_get_text        (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 PangoLayout* gtk_entry_get_layout               (GtkEntry      *entry);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_get_layout_offsets       (GtkEntry      *entry,
                                                  gint          *x,
                                                  gint          *y);
+GDK_AVAILABLE_IN_ALL
 void       gtk_entry_set_alignment              (GtkEntry      *entry,
                                                  gfloat         xalign);
+GDK_AVAILABLE_IN_ALL
 gfloat     gtk_entry_get_alignment              (GtkEntry      *entry);
 
+GDK_AVAILABLE_IN_ALL
 void                gtk_entry_set_completion (GtkEntry           *entry,
                                               GtkEntryCompletion *completion);
+GDK_AVAILABLE_IN_ALL
 GtkEntryCompletion *gtk_entry_get_completion (GtkEntry           *entry);
 
+GDK_AVAILABLE_IN_ALL
 gint       gtk_entry_layout_index_to_text_index (GtkEntry      *entry,
                                                  gint           layout_index);
+GDK_AVAILABLE_IN_ALL
 gint       gtk_entry_text_index_to_layout_index (GtkEntry      *entry,
                                                  gint           text_index);
 
 /* For scrolling cursor appropriately
  */
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_cursor_hadjustment (GtkEntry      *entry,
                                                  GtkAdjustment *adjustment);
+GDK_AVAILABLE_IN_ALL
 GtkAdjustment* gtk_entry_get_cursor_hadjustment (GtkEntry      *entry);
 
 /* Progress API
  */
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_progress_fraction   (GtkEntry     *entry,
                                                   gdouble       fraction);
+GDK_AVAILABLE_IN_ALL
 gdouble        gtk_entry_get_progress_fraction   (GtkEntry     *entry);
 
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_progress_pulse_step (GtkEntry     *entry,
                                                   gdouble       fraction);
+GDK_AVAILABLE_IN_ALL
 gdouble        gtk_entry_get_progress_pulse_step (GtkEntry     *entry);
 
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_progress_pulse          (GtkEntry     *entry);
-
+GDK_AVAILABLE_IN_3_2
+const gchar*   gtk_entry_get_placeholder_text    (GtkEntry             *entry);
+GDK_AVAILABLE_IN_3_2
+void           gtk_entry_set_placeholder_text    (GtkEntry             *entry,
+                                                  const gchar          *text);
 /* Setting and managing icons
  */
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_icon_from_pixbuf            (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  GdkPixbuf            *pixbuf);
+GDK_DEPRECATED_IN_3_10_FOR(gtk_entry_set_icon_from_icon_name)
 void           gtk_entry_set_icon_from_stock             (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  const gchar          *stock_id);
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_icon_from_icon_name         (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  const gchar          *icon_name);
+GDK_AVAILABLE_IN_ALL
 void           gtk_entry_set_icon_from_gicon             (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  GIcon                *icon);
+GDK_AVAILABLE_IN_ALL
 GtkImageType gtk_entry_get_icon_storage_type             (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 GdkPixbuf*   gtk_entry_get_icon_pixbuf                   (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_DEPRECATED_IN_3_10_FOR(gtk_entry_get_icon_name)
 const gchar* gtk_entry_get_icon_stock                    (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 const gchar* gtk_entry_get_icon_name                     (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 GIcon*       gtk_entry_get_icon_gicon                    (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_set_icon_activatable              (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  gboolean              activatable);
+GDK_AVAILABLE_IN_ALL
 gboolean     gtk_entry_get_icon_activatable              (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_set_icon_sensitive                (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  gboolean              sensitive);
+GDK_AVAILABLE_IN_ALL
 gboolean     gtk_entry_get_icon_sensitive                (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 gint         gtk_entry_get_icon_at_pos                   (GtkEntry             *entry,
 							  gint                  x,
 							  gint                  y);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_set_icon_tooltip_text             (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  const gchar          *tooltip);
+GDK_AVAILABLE_IN_ALL
 gchar *      gtk_entry_get_icon_tooltip_text             (GtkEntry             *entry,
                                                           GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_set_icon_tooltip_markup           (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  const gchar          *tooltip);
+GDK_AVAILABLE_IN_ALL
 gchar *      gtk_entry_get_icon_tooltip_markup           (GtkEntry             *entry,
                                                           GtkEntryIconPosition  icon_pos);
+GDK_AVAILABLE_IN_ALL
 void         gtk_entry_set_icon_drag_source              (GtkEntry             *entry,
 							  GtkEntryIconPosition  icon_pos,
 							  GtkTargetList        *target_list,
 							  GdkDragAction         actions);
+GDK_AVAILABLE_IN_ALL
 gint         gtk_entry_get_current_icon_drag_source      (GtkEntry             *entry);
+GDK_AVAILABLE_IN_ALL
+void         gtk_entry_get_icon_area                     (GtkEntry             *entry,
+                                                          GtkEntryIconPosition  icon_pos,
+                                                          GdkRectangle         *icon_area);
 
-GdkWindow  * gtk_entry_get_icon_window                   (GtkEntry             *entry,
-                                                          GtkEntryIconPosition  icon_pos);
-
+GDK_AVAILABLE_IN_ALL
 gboolean    gtk_entry_im_context_filter_keypress         (GtkEntry             *entry,
                                                           GdkEventKey          *event);
+GDK_AVAILABLE_IN_ALL
 void        gtk_entry_reset_im_context                   (GtkEntry             *entry);
 
+GDK_AVAILABLE_IN_3_6
+void            gtk_entry_set_input_purpose                  (GtkEntry             *entry,
+                                                              GtkInputPurpose       purpose);
+GDK_AVAILABLE_IN_3_6
+GtkInputPurpose gtk_entry_get_input_purpose                  (GtkEntry             *entry);
 
-/* Deprecated compatibility functions
- */
+GDK_AVAILABLE_IN_3_6
+void            gtk_entry_set_input_hints                    (GtkEntry             *entry,
+                                                              GtkInputHints         hints);
+GDK_AVAILABLE_IN_3_6
+GtkInputHints   gtk_entry_get_input_hints                    (GtkEntry             *entry);
 
-#ifndef GTK_DISABLE_DEPRECATED
-GtkWidget* gtk_entry_new_with_max_length	(gint           max);
-void       gtk_entry_append_text    		(GtkEntry      *entry,
-						 const gchar   *text);
-void       gtk_entry_prepend_text   		(GtkEntry      *entry,
-						 const gchar   *text);
-void       gtk_entry_set_position   		(GtkEntry      *entry,
-						 gint           position);
-void       gtk_entry_select_region  		(GtkEntry      *entry,
-						 gint           start,
-						 gint           end);
-void       gtk_entry_set_editable   		(GtkEntry      *entry,
-						 gboolean       editable);
-#endif /* GTK_DISABLE_DEPRECATED */
+GDK_AVAILABLE_IN_3_6
+void            gtk_entry_set_attributes                     (GtkEntry             *entry,
+                                                              PangoAttrList        *attrs);
+GDK_AVAILABLE_IN_3_6
+PangoAttrList  *gtk_entry_get_attributes                     (GtkEntry             *entry);
+
+GDK_AVAILABLE_IN_3_10
+void            gtk_entry_set_tabs                           (GtkEntry             *entry,
+                                                              PangoTabArray        *tabs);
+
+GDK_AVAILABLE_IN_3_10
+PangoTabArray  *gtk_entry_get_tabs                           (GtkEntry             *entry);
+
+GDK_AVAILABLE_IN_3_16
+void           gtk_entry_grab_focus_without_selecting        (GtkEntry             *entry);
 
 G_END_DECLS
 
